---
hide:
    - toc
---

```console
https://pokeapi.co/api/v2/{endpoint}/
```

!!! tip "Endpoint list"
    To see the list of available endpoints
    ```python
    from pypokeclient import ENDPOINTS


    print(ENDPOINTS)
    ```

::: pypokeclient._api.resource_lists
    options:
        separate_signature: false
